==> mingw-w64-starpu-1.4.0-2.src.tar.zst: starpu-1.4.0/doc/doxygen_web_introduction/html_web_introduction/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "StarPU Handbook - StarPU Introduction", "index.html", [
    [ "Introduction", "index.html", [
      [ "Motivation", "index.html#Motivation", null ],
      [ "StarPU in a Nutshell", "index.html#StarPUInANutshell", [
        [ "Codelet and Tasks", "index.html#CodeletAndTasks", null ],
        [ "StarPU Data Management Library", "index.html#StarPUDataManagementLibrary", null ]
      ] ],
      [ "Application Taskification", "index.html#ApplicationTaskification", null ],
      [ "Research Papers", "index.html#ResearchPapers", null ]
    ] ],
    [ "Glossary", "Glossary.html", null ],
    [ "The GNU Free Documentation License", "GNUFreeDocumentationLicense.html", [
      [ "ADDENDUM: How to use this License for your documents", "GNUFreeDocumentationLicense.html#ADDENDUM", null ]
    ] ],
    [ "", "Files.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ]
    ] ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"Files.html",
"group__API__CUDA__Extensions.html#gad7d80d054bd2b9570e1d7e24442e19c0",
"group__API__Codelet__And__Tasks.html#gabba5bab6e4eb84f21f01ba53008a0cd3",
"group__API__Data__Interfaces.html#ga07eb2ecc8ee04523993aeb0be19a8878",
"group__API__Data__Interfaces.html#gaa2f2140147f15e7b9eec1443690e357c",
"group__API__Data__Management.html#ga80b7284bb413ae7acac0fe83268c10f1",
"group__API__Data__Partition.html#gabd339fb3ebea0702e53f0dbe51b88810",
"group__API__HeteroPrio.html#gga4e0acb1eccee22933b75f4976966ed33ae28c8a80f837848e3c0d7194c8f261c2",
"group__API__Interop__Support.html#ga09441440ff5cb1618edcb54bceab9956",
"group__API__MPI__Support.html#ga74225631164f87f8ed34c36a6fe0b1b2",
"group__API__Modularized__Scheduler.html#ga063bc22ea750afba5bebe22e3117258b",
"group__API__OpenMP__Runtime__Support.html#a294032947604cf227abad87b30a08c27",
"group__API__Out__Of__Core.html#ae1c30bb72265e8d1e972bfb00cf6345e",
"group__API__Perf__Steering.html#ga667a3e2c75990008b9440408b056495f",
"group__API__Profiling.html#aa28c145b4543cceed05a1bba0478577e",
"group__API__SC__Hypervisor.html#gacb6f52f457e060e2800a3f348d641c07",
"group__API__Scheduling__Contexts.html#ga7988c6119e176957987baac65f4fc62c",
"group__API__Task__Bundles.html#gadd37abde6806819967151a64146b19d6",
"group__API__Transactions.html#ga139096b405488a9b09350503b913b67f",
"index.html#StarPUDataManagementLibrary",
"interfacefstarpu__mod_1_1fstarpu__df__alloc__vector__filter__divide__in__2.html",
"interfacefstarpu__mod_1_1fstarpu__task__wait__array.html",
"interfacestarpu__mod_1_1starpu__get__version.html",
"starpu__config_8h.html#ab216fc6c349c3f4ec15063cb71a3eafe",
"starpufft_8h.html#a7f0530e50dae8f007a739c4fb71594e4"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> mingw-w64-starpu-1.4.2-1.src.tar.zst: starpu-1.4.2/doc/doxygen_web_introduction/html_web_introduction/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "StarPU Handbook - StarPU Introduction", "index.html", [
    [ "Introduction", "index.html", [
      [ "Motivation", "index.html#Motivation", null ],
      [ "StarPU in a Nutshell", "index.html#StarPUInANutshell", [
        [ "Codelet and Tasks", "index.html#CodeletAndTasks", null ],
        [ "StarPU Data Management Library", "index.html#StarPUDataManagementLibrary", null ]
      ] ],
      [ "Application Taskification", "index.html#ApplicationTaskification", null ],
      [ "Research Papers", "index.html#ResearchPapers", null ]
    ] ],
    [ "Glossary", "Glossary.html", null ],
    [ "The GNU Free Documentation License", "GNUFreeDocumentationLicense.html", [
      [ "ADDENDUM: How to use this License for your documents", "GNUFreeDocumentationLicense.html#ADDENDUM", null ]
    ] ],
    [ "", "Files.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ]
    ] ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"Files.html",
"group__API__Codelet__And__Tasks.html#ga3c6c4dd317df02d7021e23ab6b14e3e2",
"group__API__Data__Interfaces.html#ga11d470bd48328eb4432e1c546ea22618",
"group__API__Data__Management.html#ga8db878885ebbee4729d8aed6a0479262",
"group__API__Initialization__and__Termination.html#a5eebc0c0effcab9b0f257debe96071ba",
"group__API__MPI__Support.html#ga74225631164f87f8ed34c36a6fe0b1b2",
"group__API__OpenMP__Runtime__Support.html#a6e3c542eac204dd67f343427c8a0a17c",
"group__API__Perf__Steering.html",
"group__API__SC__Hypervisor.html#ga08b6cf1458859cdeebc6e53b5dd753cb",
"group__API__Standard__Memory__Library.html#ga9e545c4701e6db29ab38bd0f7e4a76b5",
"group__API__Workers.html#gga6f3fbb6e918d0135ccb68473a8ee5ca1adba8e3eb8cbe7ba83bbd4c1707fc5ffd",
"interfacefstarpu__mod_1_1fstarpu__df__alloc__matrix__filter__block.html",
"interfacefstarpu__mod_1_1fstarpu__task__nsubmitted.html",
"starpu_8h_source.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
